==> haskell-hls-fourmolu-plugin-2.1.0.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.1.0.0-Kaf3Lz9s8CKBw4S09BdTI3
key:                  hls-fourmolu-plugin-2.1.0.0-Kaf3Lz9s8CKBw4S09BdTI3
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  d978f4631ed9554995bf946f8a696293
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.1.0.0-Kaf3Lz9s8CKBw4S09BdTI3
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.11.0.0-Jo0ziMhO7JtJZo55DUEYsU ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-8JBpStbo1B4AALTMcYIo2m
    hls-plugin-api-2.1.0.0-H3CXeXeKkzR8GXL5hkOqhn
    lens-5.3.1-LF4jCoE0w776e2gq32lhyl
    lsp-2.1.0.0-7xFRPbjxdPZ8y4wRPhO8AZ mtl-2.2.2
    process-extras-0.7.4-J6OjJnsf1pyAMhkypmGevk text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-fourmolu-plugin-2.1.0.0-26-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-fourmolu-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-fourmolu-plugin
version:              2.1.0.0
visibility:           public
id:                   hls-fourmolu-plugin-2.1.0.0-E7PpYWkH5fr5dZVmpIFfAI
key:                  hls-fourmolu-plugin-2.1.0.0-E7PpYWkH5fr5dZVmpIFfAI
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server
synopsis:             Integration with the Fourmolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  dba4c4d50310bd14a7ed9b1fe2161246
exposed:              True
exposed-modules:      Ide.Plugin.Fourmolu Ide.Plugin.Fourmolu.Shim
import-dirs:          /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hls-fourmolu-plugin-2.1.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-fourmolu-plugin
hs-libraries:         HShls-fourmolu-plugin-2.1.0.0-E7PpYWkH5fr5dZVmpIFfAI
depends:
    base-4.17.2.1 filepath-1.4.2.2
    fourmolu-0.11.0.0-LusOrQZWsahEs0rLQp5nBO ghc-9.4.8
    ghc-boot-th-9.4.8 ghcide-2.1.0.0-1VyHjvm41GN9dpQq6g7dnc
    hls-plugin-api-2.1.0.0-KgqOGj7ddh79pdBAmzh4H2
    lens-5.3.1-EQU0Jo6uxppBYuhl3GuXTA
    lsp-2.1.0.0-FIUxRBZPO0c6Yu7Vd1pRxF mtl-2.2.2
    process-extras-0.7.4-JgH59wP6fNrGDKy65hFSbC text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-hls-fourmolu-plugin/html/hls-fourmolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-fourmolu-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
